/*
        file: nntp.h
          by: Johan Svensson <johan@ecsdg.lu.se>
    email to: <NA@ecsdg.lu.se>
   copyright: Copyright (C) 1994-95 JoS-Ware Comp Tech, Sweden
        date: 1994-04-28
 last update: 1995-01-29
       notes: NNTP oriented stuff

#      This program is free software; you can redistribute it and/or modify
#      it under the terms of the GNU General Public License as published by
#      the Free Software Foundation; either version 2 of the License, or
#      (at your option) any later version.
#
#      This program is distributed in the hope that it will be useful,
#      but WITHOUT ANY WARRANTY; without even the implied warranty of
#      MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#      GNU General Public License for more details.
#
#      You should have received a copy of the GNU General Public License
#      along with this program; if not, write to the Free Software
#      Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#

*/

#define BUFFERLEN		3072
#define GROUP_MODE		1
#define SUBSCRIBED		1
#define UNSUBSCRIBED		0
#define NO_GROUP		411
#define SUBJECT_LENGTH		48
#define AUTHOR_LENGTH		23
#define ARTICLE_MODE		0
#define NEW_GROUPS		2
#define ALL_GROUPS		3
#define SUB_GROUPS		5
#define UNSUB_GROUPS		6
#define MATCH_GROUPS		7
#define ALL_ARTICLES		4
#define MAX_COMMAND_LEN		128
#define MAX_MESSAGE_LEN		512
#define MAX_ARTICLE_LEN		1024
#define POSTED_OK		240
#define NEWS_POST		1
#define MAIL_POST		0
#define MAX_NEWS_GROUPS		1000
#define MAX_ARTICLES		5000
#define MAX_SUBSCRIBED_GROUPS	100


/*
General classification of status response codes from NNTP servers
=================================================================
Each code is a three digit numeric code, specified in RFC0977.

First position
--------------
The first digit of the response broadly indicates the success,
failure, or progress of the previous command.

   1xx - Informative message
   2xx - Command ok
   3xx - Command ok so far, send the rest of it.
   4xx - Command was correct, but couldn't be performed for
         some reason.
   5xx - Command unimplemented, or incorrect, or a serious
            program error occurred.



Second position
---------------
The next digit in the code indicates the function response category.

   x0x - Connection, setup, and miscellaneous messages
   x1x - Newsgroup selection
   x2x - Article selection
   x3x - Distribution functions
   x4x - Posting
   x8x - Nonstandard (private implementation) extensions
   x9x - Debugging output


*/

/* chars for different status response code classes: */
#define	STAT_CH_INF	'1'
#define	STAT_CH_OK	'2'
#define	STAT_CH_CONT	'3'
#define	STAT_CH_ERR	'4'
#define	STAT_CH_FATAL	'5'


/* all status response codes according to rfc0977: */
#define	INF_HELP	100 /* help text follows */
#define	INF_DEBUG	199 /* debug output */

#define	OK_CANPOST	200 /* server ready - posting allowed */
#define	OK_NOPOST	201 /* server ready - no posting allowed */
#define	OK_SLAVE	202 /* slave status noted */
#define	OK_GOODBYE	205 /* closing connection - goodbye! */
#define	OK_GROUP	211 /* n f l s group selected */
#define	OK_GROUPS	215 /* list of newsgroups follows */
#define	OK_ARTICLE	220 /* n <a> article retrieved - */
                               /* head and body follow */
#define	OK_HEAD		221 /* n <a> article retrieved - */
                               /* head follows */
#define	OK_BODY		222 /* n <a> article retrieved - */
                               /* body follows */
#define	OK_NOTEXT	223 /* n <a> article retrieved - */
                               /* request text separately */
#define	OK_NEWNEWS	230 /* list of new articles by */
                               /* message-id follows */
#define	OK_NEWGROUPS	231 /* list of new newsgroups follows */
#define	OK_XFERED	235 /* article transferred ok */
#define	OK_POSTED	240 /* article posted ok */

#define CONT_XFER	335 /* send article to be transferred. */
                               /* End with <CR-LF>.<CR-LF> */
#define	CONT_POST	340 /* send article to be posted. */
                               /*End with <CR-LF>.<CR-LF> */

#define	ERR_GOODBYE	400 /* service discontinued */
#define	ERR_NOGROUP	411 /* no such news group */
#define	ERR_NCING	412 /* no newsgroup has been selected */
#define	ERR_NOCRNT	420 /* no current article has been selected */
#define	ERR_NONEXT	421 /* no next article in this group */
#define	ERR_NOPREV	422 /* no previous article in this group */
#define	ERR_NOARTIG	423 /* no such article number in this group */
#define ERR_NOART	430 /* no such article found */
#define ERR_GOTIT	435 /* article not wanted - do not send it */
#define ERR_XFERFAIL	436 /* transfer failed - try again later */
#define	ERR_XFERRJCT	437 /* article rejected - do not try again */
#define	ERR_NOPOST	440 /* posting not allowed */
#define	ERR_POSTFAIL	441 /* posting failed */

#define	ERR_COMMAND	500 /* command not recognized */
#define	ERR_CMDSYN	501 /* command syntax error */
#define	ERR_ACCESS	502 /* access restriction or permission denied */
#define ERR_FAULT	503 /* program fault - command not performed */

/* externals from str.c: */
extern char *strnset         (char *s, int ch, size_t n);
extern char *strupr          (char *str);
extern char *strunhtml       (char *str);

/* internal functions: */
SWORD socket_connect(char*);
SWORD put_server(char*);
SWORD get_server(char*, SDWORD);
void  close_server(void);
SWORD connect_server(char*);
SWORD reconnect_server(char*);
SWORD nntp_connect(char*);
void  getauthorlist(char*, char**, SDWORD, SDWORD, SDWORD);
